@@ -4,7 +4,6 @@ from fastapi import FastAPI
 from compass.api.routes import authentication
 from compass.api.routes import hierarchy
 from compass.api.routes import members
-from compass.api.util import redis
 
 open_api_tag_metadata = [
     {
@@ -34,10 +33,9 @@ and is licensed under the **[MIT license](https://choosealicense.com/licenses/mi
 app = FastAPI(
     title="Compass Interface — the unofficial Compass API",
     description=long_description,
-    version="0.24.1",
+    version="0.24.2",
     openapi_tags=open_api_tag_metadata,
 )
-app.router.lifespan_context = redis.lifetime
 
 # V1 Routing
 version_one = APIRouter()
