@@ -12,11 +12,10 @@ router = fastapi.APIRouter()
 
 
 @router.post("/", response_model=auth.Token)
-async def login_for_access_token(request: requests.Request, form_data: auth.OAuth2Details = auth.Form(...)) -> auth.Token:
+async def login_for_access_token(form_data: auth.OAuth2Details = auth.Form(...)) -> auth.Token:
     logger.debug(f"Requested token endpoint with form data: {form_data.__dict__}")
     try:
-        store = request.app.state.redis
-        access_token = await create_token(form_data.username, form_data.password, form_data.role, form_data.location, store)
+        access_token = await create_token(form_data.username, form_data.password, form_data.role, form_data.location)
     except exceptions.HTTPException as err:
         raise err
     except Exception:
